==> haskell-zip-archive-0.3.0.2-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-zip-archive/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: zip-archive
version: 0.3.0.2
id: zip-archive-0.3.0.2-15b8e9a70ed3ab3db3683741297aa226
key: zipar_5cVNzr8QTs6IaB6wCygXAT
license: BSD3
maintainer: jgm@berkeley.edu
homepage: http://github.com/jgm/zip-archive
synopsis: Library for creating and modifying zip archives.
description:
    The zip-archive library provides functions for creating, modifying,
    and extracting files from zip archives.
category: Codec
author: John MacFarlane
exposed: True
exposed-modules:
    Codec.Archive.Zip
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/zip-archive-0.3.0.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/zip-archive-0.3.0.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/zip-archive-0.3.0.2
hs-libraries: HSzip-archive-0.3.0.2-5cVNzr8QTs6IaB6wCygXAT
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    digest-0.0.1.2-f499fd5747664c706c76dcc742b23f54
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    pretty-1.1.2.0-b06321e1e395640194b358a5374c465f
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
haddock-interfaces: /usr/share/doc/haskell-zip-archive/html/zip-archive.haddock
haddock-html: /usr/share/doc/haskell-zip-archive/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zip-archive-0.3-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-zip-archive/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: zip-archive
version: 0.3
id: zip-archive-0.3-2c98cfc50f306ecd4e01363be7a8d981
key: zipar_ByuDZeQwtUa1yrYaUyN3pp
license: BSD3
maintainer: jgm@berkeley.edu
homepage: http://github.com/jgm/zip-archive
synopsis: Library for creating and modifying zip archives.
description:
    The zip-archive library provides functions for creating, modifying,
    and extracting files from zip archives.
category: Codec
author: John MacFarlane
exposed: True
exposed-modules:
    Codec.Archive.Zip
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/zip-archive-0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/zip-archive-0.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/zip-archive-0.3
hs-libraries: HSzip-archive-0.3-ByuDZeQwtUa1yrYaUyN3pp
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    digest-0.0.1.2-f499fd5747664c706c76dcc742b23f54
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    pretty-1.1.2.0-b06321e1e395640194b358a5374c465f
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
haddock-interfaces: /usr/share/doc/haskell-zip-archive/html/zip-archive.haddock
haddock-html: /usr/share/doc/haskell-zip-archive/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
